pub unsafe extern "C" fn sodot_dealloc_heap_string(self_: HeapString)Expand description
Deallocates the heap array This should be called after the struct is no longer needed
pub unsafe extern "C" fn sodot_dealloc_heap_string(self_: HeapString)Deallocates the heap array This should be called after the struct is no longer needed